@@ -27,7 +27,13 @@ from .client import (
     AttachmentType,
 )
 
-__version__ = "2.1.17"
+from .types import (
+    MessageContentBlock,
+    ChatMessage,
+    RunMessageHistory,
+)
+
+__version__ = "2.1.19"
 
 __all__ = [
     "CyberdeskClient",
@@ -54,4 +60,7 @@ __all__ = [
     "RunAttachmentResponse",
     "RunAttachmentDownloadUrlResponse",
     "AttachmentType",
+    "MessageContentBlock",
+    "ChatMessage",
+    "RunMessageHistory",
 ] 
\ No newline at end of file
