@@ -1,5 +1,5 @@
 """Cyberdesk Python SDK Client."""
-from typing import Optional, Dict, Any, Union, List
+from typing import Optional, Dict, Any, Union, List, TypeVar, Generic
 from uuid import UUID
 from pathlib import Path
 import httpx
@@ -155,10 +155,12 @@ __all__ = [
 DEFAULT_API_BASE_URL = "https://api.cyberdesk.io"
 
 
+T = TypeVar('T')
+
 @dataclass
-class ApiResponse:
+class ApiResponse(Generic[T]):
     """Wrapper for API responses."""
-    data: Optional[Any] = None
+    data: Optional[T] = None
     error: Optional[Any] = None
 
 
@@ -208,7 +210,7 @@ class MachinesAPI:
         *,
         created_at_from: Optional[Union[str, datetime]] = None,
         created_at_to: Optional[Union[str, datetime]] = None,
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseMachineResponse]:
         """List machines with optional filtering.
 
         Args:
@@ -243,7 +245,7 @@ class MachinesAPI:
         *,
         created_at_from: Optional[Union[str, datetime]] = None,
         created_at_to: Optional[Union[str, datetime]] = None,
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseMachineResponse]:
         """List machines with optional filtering (synchronous).
         
         Args:
@@ -270,7 +272,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def create(self, data: MachineCreate) -> ApiResponse:
+    async def create(self, data: MachineCreate) -> ApiResponse[MachineResponse]:
         """Create a new machine.
         
         Args:
@@ -292,7 +294,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def create_sync(self, data: MachineCreate) -> ApiResponse:
+    def create_sync(self, data: MachineCreate) -> ApiResponse[MachineResponse]:
         """Create a new machine (synchronous).
         
         Args:
@@ -314,7 +316,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def get(self, machine_id: str) -> ApiResponse:
+    async def get(self, machine_id: str) -> ApiResponse[MachineResponse]:
         """Get a specific machine by ID.
         
         Returns:
@@ -333,7 +335,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def get_sync(self, machine_id: str) -> ApiResponse:
+    def get_sync(self, machine_id: str) -> ApiResponse[MachineResponse]:
         """Get a specific machine by ID (synchronous).
         
         Returns:
@@ -352,7 +354,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def update(self, machine_id: str, data: MachineUpdate) -> ApiResponse:
+    async def update(self, machine_id: str, data: MachineUpdate) -> ApiResponse[MachineResponse]:
         """Update a machine.
         
         Args:
@@ -387,7 +389,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def update_sync(self, machine_id: str, data: MachineUpdate) -> ApiResponse:
+    def update_sync(self, machine_id: str, data: MachineUpdate) -> ApiResponse[MachineResponse]:
         """Update a machine (synchronous).
         
         Args:
@@ -422,7 +424,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def clear_session(self, machine_id: str) -> ApiResponse:
+    async def clear_session(self, machine_id: str) -> ApiResponse[MachineResponse]:
         """Clear the machine's reserved session (cancels queued/running session runs).
 
         This sends reserved_session_id=null per API contract.
@@ -438,7 +440,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def clear_session_sync(self, machine_id: str) -> ApiResponse:
+    def clear_session_sync(self, machine_id: str) -> ApiResponse[MachineResponse]:
         """Clear the machine's reserved session (synchronous)."""
         try:
             update = MachineUpdate(reserved_session_id=None)
@@ -451,7 +453,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def delete(self, machine_id: str) -> ApiResponse:
+    async def delete(self, machine_id: str) -> ApiResponse[MachineResponse]:
         """Delete a machine.
         
         Associated runs are preserved with machine_id set to NULL to maintain run history.
@@ -469,7 +471,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def delete_sync(self, machine_id: str) -> ApiResponse:
+    def delete_sync(self, machine_id: str) -> ApiResponse[MachineResponse]:
         """Delete a machine (synchronous).
         
         Associated runs are preserved with machine_id set to NULL to maintain run history.
@@ -487,7 +489,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def get_pools(self, machine_id: str) -> ApiResponse:
+    async def get_pools(self, machine_id: str) -> ApiResponse[List[PoolResponse]]:
         """Get all pools that a machine belongs to."""
         try:
             response = await get_machine_pools_v1_machines_machine_id_pools_get.asyncio(
@@ -498,7 +500,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def get_pools_sync(self, machine_id: str) -> ApiResponse:
+    def get_pools_sync(self, machine_id: str) -> ApiResponse[List[PoolResponse]]:
         """Get all pools that a machine belongs to (synchronous)."""
         try:
             response = get_machine_pools_v1_machines_machine_id_pools_get.sync(
@@ -509,7 +511,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def update_pools(self, machine_id: str, data: MachinePoolUpdate) -> ApiResponse:
+    async def update_pools(self, machine_id: str, data: MachinePoolUpdate) -> ApiResponse[List[PoolResponse]]:
         """Update a machine's pool assignments.
         
         This replaces all existing pool assignments with the new ones.
@@ -531,7 +533,7 @@ class MachinesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def update_pools_sync(self, machine_id: str, data: MachinePoolUpdate) -> ApiResponse:
+    def update_pools_sync(self, machine_id: str, data: MachinePoolUpdate) -> ApiResponse[List[PoolResponse]]:
         """Update a machine's pool assignments (synchronous).
         
         This replaces all existing pool assignments with the new ones.
@@ -564,7 +566,7 @@ class PoolsAPI:
         self,
         skip: Optional[int] = None,
         limit: Optional[int] = None
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponsePoolResponse]:
         """List pools for the organization."""
         try:
             response = await list_pools_v1_pools_get.asyncio(
@@ -580,7 +582,7 @@ class PoolsAPI:
         self,
         skip: Optional[int] = None,
         limit: Optional[int] = None
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponsePoolResponse]:
         """List pools for the organization (synchronous)."""
         try:
             response = list_pools_v1_pools_get.sync(
@@ -592,7 +594,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def create(self, data: PoolCreate) -> ApiResponse:
+    async def create(self, data: PoolCreate) -> ApiResponse[PoolResponse]:
         """Create a new pool."""
         try:
             response = await create_pool_v1_pools_post.asyncio(
@@ -603,7 +605,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def create_sync(self, data: PoolCreate) -> ApiResponse:
+    def create_sync(self, data: PoolCreate) -> ApiResponse[PoolResponse]:
         """Create a new pool (synchronous)."""
         try:
             response = create_pool_v1_pools_post.sync(
@@ -614,7 +616,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def get(self, pool_id: str, include_machines: bool = False) -> ApiResponse:
+    async def get(self, pool_id: str, include_machines: bool = False) -> ApiResponse[Union[PoolResponse, PoolWithMachines]]:
         """Get a specific pool by ID.
         
         Args:
@@ -634,7 +636,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def get_sync(self, pool_id: str, include_machines: bool = False) -> ApiResponse:
+    def get_sync(self, pool_id: str, include_machines: bool = False) -> ApiResponse[Union[PoolResponse, PoolWithMachines]]:
         """Get a specific pool by ID (synchronous).
         
         Args:
@@ -654,7 +656,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def update(self, pool_id: str, data: PoolUpdate) -> ApiResponse:
+    async def update(self, pool_id: str, data: PoolUpdate) -> ApiResponse[PoolResponse]:
         """Update a pool's details."""
         try:
             response = await update_pool_v1_pools_pool_id_patch.asyncio(
@@ -666,7 +668,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def update_sync(self, pool_id: str, data: PoolUpdate) -> ApiResponse:
+    def update_sync(self, pool_id: str, data: PoolUpdate) -> ApiResponse[PoolResponse]:
         """Update a pool's details (synchronous)."""
         try:
             response = update_pool_v1_pools_pool_id_patch.sync(
@@ -678,7 +680,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def delete(self, pool_id: str) -> ApiResponse:
+    async def delete(self, pool_id: str) -> ApiResponse[PoolResponse]:
         """Delete a pool. This will not delete the machines in the pool."""
         try:
             await delete_pool_v1_pools_pool_id_delete.asyncio(
@@ -689,7 +691,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def delete_sync(self, pool_id: str) -> ApiResponse:
+    def delete_sync(self, pool_id: str) -> ApiResponse[PoolResponse]:
         """Delete a pool. This will not delete the machines in the pool (synchronous)."""
         try:
             delete_pool_v1_pools_pool_id_delete.sync(
@@ -700,7 +702,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def add_machines(self, pool_id: str, data: MachinePoolAssignment) -> ApiResponse:
+    async def add_machines(self, pool_id: str, data: MachinePoolAssignment) -> ApiResponse[PoolWithMachines]:
         """Add machines to a pool.
         
         Args:
@@ -720,7 +722,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def add_machines_sync(self, pool_id: str, data: MachinePoolAssignment) -> ApiResponse:
+    def add_machines_sync(self, pool_id: str, data: MachinePoolAssignment) -> ApiResponse[PoolWithMachines]:
         """Add machines to a pool (synchronous).
         
         Args:
@@ -740,7 +742,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def remove_machines(self, pool_id: str, data: MachinePoolAssignment) -> ApiResponse:
+    async def remove_machines(self, pool_id: str, data: MachinePoolAssignment) -> ApiResponse[PoolWithMachines]:
         """Remove machines from a pool.
         
         Args:
@@ -760,7 +762,7 @@ class PoolsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def remove_machines_sync(self, pool_id: str, data: MachinePoolAssignment) -> ApiResponse:
+    def remove_machines_sync(self, pool_id: str, data: MachinePoolAssignment) -> ApiResponse[PoolWithMachines]:
         """Remove machines from a pool (synchronous).
         
         Args:
@@ -796,7 +798,7 @@ class WorkflowsAPI:
         created_at_to: Optional[Union[str, datetime]] = None,
         updated_at_from: Optional[Union[str, datetime]] = None,
         updated_at_to: Optional[Union[str, datetime]] = None,
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseWorkflowResponse]:
         """List workflows with optional date-time filtering.
 
         Args:
@@ -830,7 +832,7 @@ class WorkflowsAPI:
         created_at_to: Optional[Union[str, datetime]] = None,
         updated_at_from: Optional[Union[str, datetime]] = None,
         updated_at_to: Optional[Union[str, datetime]] = None,
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseWorkflowResponse]:
         """List workflows (synchronous) with optional date-time filtering."""
         try:
             response = list_workflows_v1_workflows_get.sync(
@@ -846,7 +848,7 @@ class WorkflowsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def create(self, data: WorkflowCreate) -> ApiResponse:
+    async def create(self, data: WorkflowCreate) -> ApiResponse[WorkflowResponse]:
         """Create a new workflow."""
         try:
             response = await create_workflow_v1_workflows_post.asyncio(
@@ -857,7 +859,7 @@ class WorkflowsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def create_sync(self, data: WorkflowCreate) -> ApiResponse:
+    def create_sync(self, data: WorkflowCreate) -> ApiResponse[WorkflowResponse]:
         """Create a new workflow (synchronous)."""
         try:
             response = create_workflow_v1_workflows_post.sync(
@@ -868,7 +870,7 @@ class WorkflowsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def get(self, workflow_id: str) -> ApiResponse:
+    async def get(self, workflow_id: str) -> ApiResponse[WorkflowResponse]:
         """Get a specific workflow by ID."""
         try:
             response = await get_workflow_v1_workflows_workflow_id_get.asyncio(
@@ -879,7 +881,7 @@ class WorkflowsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def get_sync(self, workflow_id: str) -> ApiResponse:
+    def get_sync(self, workflow_id: str) -> ApiResponse[WorkflowResponse]:
         """Get a specific workflow by ID (synchronous)."""
         try:
             response = get_workflow_v1_workflows_workflow_id_get.sync(
@@ -890,7 +892,7 @@ class WorkflowsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def update(self, workflow_id: str, data: WorkflowUpdate) -> ApiResponse:
+    async def update(self, workflow_id: str, data: WorkflowUpdate) -> ApiResponse[WorkflowResponse]:
         """Update a workflow."""
         try:
             response = await update_workflow_v1_workflows_workflow_id_patch.asyncio(
@@ -902,7 +904,7 @@ class WorkflowsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def update_sync(self, workflow_id: str, data: WorkflowUpdate) -> ApiResponse:
+    def update_sync(self, workflow_id: str, data: WorkflowUpdate) -> ApiResponse[WorkflowResponse]:
         """Update a workflow (synchronous)."""
         try:
             response = update_workflow_v1_workflows_workflow_id_patch.sync(
@@ -914,7 +916,7 @@ class WorkflowsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def delete(self, workflow_id: str) -> ApiResponse:
+    async def delete(self, workflow_id: str) -> ApiResponse[WorkflowResponse]:
         """Delete a workflow."""
         try:
             await delete_workflow_v1_workflows_workflow_id_delete.asyncio(
@@ -925,7 +927,7 @@ class WorkflowsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def delete_sync(self, workflow_id: str) -> ApiResponse:
+    def delete_sync(self, workflow_id: str) -> ApiResponse[WorkflowResponse]:
         """Delete a workflow (synchronous)."""
         try:
             delete_workflow_v1_workflows_workflow_id_delete.sync(
@@ -955,7 +957,7 @@ class RunsAPI:
         created_at_from: Optional[Union[str, datetime]] = None,
         created_at_to: Optional[Union[str, datetime]] = None,
         fields: Optional[List[RunField]] = None,
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseRunResponse]:
         """List runs with optional filtering.
 
         Args:
@@ -1000,7 +1002,7 @@ class RunsAPI:
         created_at_from: Optional[Union[str, datetime]] = None,
         created_at_to: Optional[Union[str, datetime]] = None,
         fields: Optional[List[RunField]] = None,
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseRunResponse]:
         """List runs with optional filtering (synchronous).
 
         See async variant for parameter docs. Supports `fields` projection.
@@ -1022,7 +1024,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
 
-    async def retry(self, run_id: str, retry: RunRetry) -> ApiResponse:
+    async def retry(self, run_id: str, retry: RunRetry) -> ApiResponse[RunResponse]:
         """Retry an existing run in-place (same run_id).
 
         Clears previous outputs/history/output attachments, optionally replaces inputs/files,
@@ -1038,7 +1040,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
 
-    def retry_sync(self, run_id: str, retry: RunRetry) -> ApiResponse:
+    def retry_sync(self, run_id: str, retry: RunRetry) -> ApiResponse[RunResponse]:
         """Retry an existing run in-place (synchronous)."""
         try:
             response = retry_run_v1_runs_run_id_retry_post.sync(
@@ -1050,7 +1052,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def create(self, data: RunCreate) -> ApiResponse:
+    async def create(self, data: RunCreate) -> ApiResponse[RunResponse]:
         """Create a new run.
         
         Args:
@@ -1078,7 +1080,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def create_sync(self, data: RunCreate) -> ApiResponse:
+    def create_sync(self, data: RunCreate) -> ApiResponse[RunResponse]:
         """Create a new run (synchronous).
         
         Args:
@@ -1106,7 +1108,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def get(self, run_id: str) -> ApiResponse:
+    async def get(self, run_id: str) -> ApiResponse[RunResponse]:
         """Get a specific run by ID."""
         try:
             response = await get_run_v1_runs_run_id_get.asyncio(
@@ -1117,7 +1119,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def get_sync(self, run_id: str) -> ApiResponse:
+    def get_sync(self, run_id: str) -> ApiResponse[RunResponse]:
         """Get a specific run by ID (synchronous)."""
         try:
             response = get_run_v1_runs_run_id_get.sync(
@@ -1128,7 +1130,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def update(self, run_id: str, data: RunUpdate) -> ApiResponse:
+    async def update(self, run_id: str, data: RunUpdate) -> ApiResponse[RunResponse]:
         """Update a run."""
         try:
             response = await update_run_v1_runs_run_id_patch.asyncio(
@@ -1140,7 +1142,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def update_sync(self, run_id: str, data: RunUpdate) -> ApiResponse:
+    def update_sync(self, run_id: str, data: RunUpdate) -> ApiResponse[RunResponse]:
         """Update a run (synchronous)."""
         try:
             response = update_run_v1_runs_run_id_patch.sync(
@@ -1152,7 +1154,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def delete(self, run_id: str) -> ApiResponse:
+    async def delete(self, run_id: str) -> ApiResponse[RunResponse]:
         """Delete a run."""
         try:
             await delete_run_v1_runs_run_id_delete.asyncio(
@@ -1163,7 +1165,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def delete_sync(self, run_id: str) -> ApiResponse:
+    def delete_sync(self, run_id: str) -> ApiResponse[RunResponse]:
         """Delete a run (synchronous)."""
         try:
             delete_run_v1_runs_run_id_delete.sync(
@@ -1174,7 +1176,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def bulk_create(self, data: RunBulkCreate) -> ApiResponse:
+    async def bulk_create(self, data: RunBulkCreate) -> ApiResponse[RunBulkCreateResponse]:
         """Create multiple runs with the same configuration.
         
         This method efficiently creates multiple runs:
@@ -1209,7 +1211,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def bulk_create_sync(self, data: RunBulkCreate) -> ApiResponse:
+    def bulk_create_sync(self, data: RunBulkCreate) -> ApiResponse[RunBulkCreateResponse]:
         """Create multiple runs with the same configuration (synchronous).
         
         This method efficiently creates multiple runs:
@@ -1244,7 +1246,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
 
-    async def chain(self, data: WorkflowChainCreate) -> ApiResponse:
+    async def chain(self, data: WorkflowChainCreate) -> ApiResponse[WorkflowChainResponse]:
         """Create a multi-step chain that runs on a single reserved session/machine.
 
         Args:
@@ -1264,7 +1266,7 @@ class RunsAPI:
         except Exception as e:
             return ApiResponse(error=e)
 
-    def chain_sync(self, data: WorkflowChainCreate) -> ApiResponse:
+    def chain_sync(self, data: WorkflowChainCreate) -> ApiResponse[WorkflowChainResponse]:
         """Create a multi-step chain (synchronous).
 
         Args:
@@ -1297,7 +1299,7 @@ class ConnectionsAPI:
         limit: Optional[int] = None,
         machine_id: Optional[str] = None,
         status: Optional[Union[str, ConnectionStatus]] = None
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseConnectionResponse]:
         """List connections with optional filtering."""
         try:
             # Handle status conversion
@@ -1321,7 +1323,7 @@ class ConnectionsAPI:
         limit: Optional[int] = None,
         machine_id: Optional[str] = None,
         status: Optional[Union[str, ConnectionStatus]] = None
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseConnectionResponse]:
         """List connections with optional filtering (synchronous)."""
         try:
             # Handle status conversion
@@ -1339,7 +1341,7 @@ class ConnectionsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def create(self, data: ConnectionCreate) -> ApiResponse:
+    async def create(self, data: ConnectionCreate) -> ApiResponse[ConnectionResponse]:
         """Create a new connection."""
         try:
             response = await create_connection_v1_connections_post.asyncio(
@@ -1350,7 +1352,7 @@ class ConnectionsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def create_sync(self, data: ConnectionCreate) -> ApiResponse:
+    def create_sync(self, data: ConnectionCreate) -> ApiResponse[ConnectionResponse]:
         """Create a new connection (synchronous)."""
         try:
             response = create_connection_v1_connections_post.sync(
@@ -1379,7 +1381,7 @@ class TrajectoriesAPI:
         created_at_to: Optional[Union[str, datetime]] = None,
         updated_at_from: Optional[Union[str, datetime]] = None,
         updated_at_to: Optional[Union[str, datetime]] = None,
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseTrajectoryResponse]:
         """List trajectories with optional filtering.
         
         Args:
@@ -1422,7 +1424,7 @@ class TrajectoriesAPI:
         created_at_to: Optional[Union[str, datetime]] = None,
         updated_at_from: Optional[Union[str, datetime]] = None,
         updated_at_to: Optional[Union[str, datetime]] = None,
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseTrajectoryResponse]:
         """List trajectories with optional filtering (synchronous).
         
         Args:
@@ -1454,7 +1456,7 @@ class TrajectoriesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def create(self, data: TrajectoryCreate) -> ApiResponse:
+    async def create(self, data: TrajectoryCreate) -> ApiResponse[TrajectoryResponse]:
         """Create a new trajectory.
         
         Note: Trajectories are created with is_approved=False by default.
@@ -1469,7 +1471,7 @@ class TrajectoriesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def create_sync(self, data: TrajectoryCreate) -> ApiResponse:
+    def create_sync(self, data: TrajectoryCreate) -> ApiResponse[TrajectoryResponse]:
         """Create a new trajectory (synchronous).
         
         Note: Trajectories are created with is_approved=False by default.
@@ -1484,7 +1486,7 @@ class TrajectoriesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def get(self, trajectory_id: str) -> ApiResponse:
+    async def get(self, trajectory_id: str) -> ApiResponse[TrajectoryResponse]:
         """Get a specific trajectory by ID."""
         try:
             response = await get_trajectory_v1_trajectories_trajectory_id_get.asyncio(
@@ -1495,7 +1497,7 @@ class TrajectoriesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def get_sync(self, trajectory_id: str) -> ApiResponse:
+    def get_sync(self, trajectory_id: str) -> ApiResponse[TrajectoryResponse]:
         """Get a specific trajectory by ID (synchronous)."""
         try:
             response = get_trajectory_v1_trajectories_trajectory_id_get.sync(
@@ -1506,7 +1508,7 @@ class TrajectoriesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def update(self, trajectory_id: str, data: TrajectoryUpdate) -> ApiResponse:
+    async def update(self, trajectory_id: str, data: TrajectoryUpdate) -> ApiResponse[TrajectoryResponse]:
         """Update a trajectory.
         
         You can update trajectory metadata (name, description), trajectory data (steps),
@@ -1523,7 +1525,7 @@ class TrajectoriesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def update_sync(self, trajectory_id: str, data: TrajectoryUpdate) -> ApiResponse:
+    def update_sync(self, trajectory_id: str, data: TrajectoryUpdate) -> ApiResponse[TrajectoryResponse]:
         """Update a trajectory (synchronous).
         
         You can update trajectory metadata (name, description), trajectory data (steps),
@@ -1540,7 +1542,7 @@ class TrajectoriesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def delete(self, trajectory_id: str) -> ApiResponse:
+    async def delete(self, trajectory_id: str) -> ApiResponse[TrajectoryResponse]:
         """Delete a trajectory."""
         try:
             await delete_trajectory_v1_trajectories_trajectory_id_delete.asyncio(
@@ -1551,7 +1553,7 @@ class TrajectoriesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def delete_sync(self, trajectory_id: str) -> ApiResponse:
+    def delete_sync(self, trajectory_id: str) -> ApiResponse[TrajectoryResponse]:
         """Delete a trajectory (synchronous)."""
         try:
             delete_trajectory_v1_trajectories_trajectory_id_delete.sync(
@@ -1562,7 +1564,7 @@ class TrajectoriesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def get_latest_for_workflow(self, workflow_id: str) -> ApiResponse:
+    async def get_latest_for_workflow(self, workflow_id: str) -> ApiResponse[TrajectoryResponse]:
         """Get the latest trajectory for a workflow."""
         try:
             response = await get_latest_trajectory_for_workflow_v1_workflows_workflow_id_latest_trajectory_get.asyncio(
@@ -1573,7 +1575,7 @@ class TrajectoriesAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def get_latest_for_workflow_sync(self, workflow_id: str) -> ApiResponse:
+    def get_latest_for_workflow_sync(self, workflow_id: str) -> ApiResponse[TrajectoryResponse]:
         """Get the latest trajectory for a workflow (synchronous)."""
         try:
             response = get_latest_trajectory_for_workflow_v1_workflows_workflow_id_latest_trajectory_get.sync(
@@ -1597,7 +1599,7 @@ class RunAttachmentsAPI:
         limit: Optional[int] = None,
         run_id: Optional[str] = None,
         attachment_type: Optional[AttachmentType] = None
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseRunAttachmentResponse]:
         """List run attachments with optional filtering."""
         try:
             response = await list_run_attachments_v1_run_attachments_get.asyncio(
@@ -1617,7 +1619,7 @@ class RunAttachmentsAPI:
         limit: Optional[int] = None,
         run_id: Optional[str] = None,
         attachment_type: Optional[AttachmentType] = None
-    ) -> ApiResponse:
+    ) -> ApiResponse[PaginatedResponseRunAttachmentResponse]:
         """List run attachments with optional filtering (synchronous)."""
         try:
             response = list_run_attachments_v1_run_attachments_get.sync(
@@ -1631,7 +1633,7 @@ class RunAttachmentsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def create(self, data: RunAttachmentCreate) -> ApiResponse:
+    async def create(self, data: RunAttachmentCreate) -> ApiResponse[RunAttachmentResponse]:
         """Create a new run attachment."""
         try:
             response = await create_run_attachment_v1_run_attachments_post.asyncio(
@@ -1642,7 +1644,7 @@ class RunAttachmentsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def create_sync(self, data: RunAttachmentCreate) -> ApiResponse:
+    def create_sync(self, data: RunAttachmentCreate) -> ApiResponse[RunAttachmentResponse]:
         """Create a new run attachment (synchronous)."""
         try:
             response = create_run_attachment_v1_run_attachments_post.sync(
@@ -1653,7 +1655,7 @@ class RunAttachmentsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def get(self, attachment_id: str) -> ApiResponse:
+    async def get(self, attachment_id: str) -> ApiResponse[RunAttachmentResponse]:
         """Get a specific run attachment by ID."""
         try:
             response = await get_run_attachment_v1_run_attachments_attachment_id_get.asyncio(
@@ -1664,7 +1666,7 @@ class RunAttachmentsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def get_sync(self, attachment_id: str) -> ApiResponse:
+    def get_sync(self, attachment_id: str) -> ApiResponse[RunAttachmentResponse]:
         """Get a specific run attachment by ID (synchronous)."""
         try:
             response = get_run_attachment_v1_run_attachments_attachment_id_get.sync(
@@ -1679,7 +1681,7 @@ class RunAttachmentsAPI:
         self, 
         attachment_id: str,
         expires_in: Optional[int] = None
-    ) -> ApiResponse:
+    ) -> ApiResponse[RunAttachmentDownloadUrlResponse]:
         """Get a signed download URL for a run attachment.
         
         The returned URL will trigger an automatic download when accessed in a browser.
@@ -1707,7 +1709,7 @@ class RunAttachmentsAPI:
         self, 
         attachment_id: str,
         expires_in: Optional[int] = None
-    ) -> ApiResponse:
+    ) -> ApiResponse[RunAttachmentDownloadUrlResponse]:
         """Get a signed download URL for a run attachment (synchronous).
         
         The returned URL will trigger an automatic download when accessed in a browser.
@@ -1731,7 +1733,7 @@ class RunAttachmentsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def download(self, attachment_id: str) -> ApiResponse:
+    async def download(self, attachment_id: str) -> ApiResponse[bytes]:
         """Download a run attachment file directly.
         
         This method returns the raw file content as bytes. For a download URL instead,
@@ -1752,7 +1754,7 @@ class RunAttachmentsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def download_sync(self, attachment_id: str) -> ApiResponse:
+    def download_sync(self, attachment_id: str) -> ApiResponse[bytes]:
         """Download a run attachment file directly (synchronous).
         
         This method returns the raw file content as bytes. For a download URL instead,
@@ -1773,7 +1775,7 @@ class RunAttachmentsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def update(self, attachment_id: str, data: RunAttachmentUpdate) -> ApiResponse:
+    async def update(self, attachment_id: str, data: RunAttachmentUpdate) -> ApiResponse[RunAttachmentResponse]:
         """Update a run attachment (e.g., set expiration)."""
         try:
             response = await update_run_attachment_v1_run_attachments_attachment_id_put.asyncio(
@@ -1785,7 +1787,7 @@ class RunAttachmentsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def update_sync(self, attachment_id: str, data: RunAttachmentUpdate) -> ApiResponse:
+    def update_sync(self, attachment_id: str, data: RunAttachmentUpdate) -> ApiResponse[RunAttachmentResponse]:
         """Update a run attachment (e.g., set expiration) (synchronous)."""
         try:
             response = update_run_attachment_v1_run_attachments_attachment_id_put.sync(
@@ -1797,7 +1799,7 @@ class RunAttachmentsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    async def delete(self, attachment_id: str) -> ApiResponse:
+    async def delete(self, attachment_id: str) -> ApiResponse[RunAttachmentResponse]:
         """Delete a run attachment."""
         try:
             await delete_run_attachment_v1_run_attachments_attachment_id_delete.asyncio(
@@ -1808,7 +1810,7 @@ class RunAttachmentsAPI:
         except Exception as e:
             return ApiResponse(error=e)
     
-    def delete_sync(self, attachment_id: str) -> ApiResponse:
+    def delete_sync(self, attachment_id: str) -> ApiResponse[RunAttachmentResponse]:
         """Delete a run attachment (synchronous)."""
         try:
             delete_run_attachment_v1_run_attachments_attachment_id_delete.sync(
@@ -1824,7 +1826,7 @@ class RunAttachmentsAPI:
         attachment_id: str,
         output_path: Optional[Union[str, Path]] = None,
         use_original_filename: bool = True
-    ) -> ApiResponse:
+    ) -> ApiResponse[Dict[str, Any]]:
         """Download and save a run attachment to a file.
         
         This is a convenience method that combines getting attachment info
@@ -1873,7 +1875,7 @@ class RunAttachmentsAPI:
         attachment_id: str,
         output_path: Optional[Union[str, Path]] = None,
         use_original_filename: bool = True
-    ) -> ApiResponse:
+    ) -> ApiResponse[Dict[str, Any]]:
         """Download and save a run attachment to a file (synchronous).
         
         This is a convenience method that combines getting attachment info
